#
# spec file for package pinta
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pinta
Version:        1.7.1
Release:        1.8
Summary:        Image editing application
License:        MIT
Group:          Productivity/Graphics/Bitmap Editors
URL:            https://pinta-project.com/
Source:         https://github.com/PintaProject/Pinta/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  mono-addins-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glib-sharp-2.0)
BuildRequires:  pkgconfig(gtk-sharp-2.0)
BuildRequires:  pkgconfig(mono) >= 6.0
BuildRequires:  pkgconfig(mono-cairo)
BuildArch:      noarch

%description
Pinta is a free, open source drawing/editing application designed
after Paint.NET. Its goal is to provide users with a simple yet
powerful way to draw and manipulate images.

%lang_package

%prep
%autosetup

%build
%configure --libdir=%{_prefix}/lib/mono/%{name}/
%make_build

%install
%make_install
rm -rf %{buildroot}%{_prefix}/lib/mono/%{name}/pkgconfig/
%find_lang %{name}

%check
make check

%files
%license license-mit.txt
%doc readme.md
%{_bindir}/%{name}
%{_prefix}/lib/mono/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.xpm
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Dec 30 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 1.7.1
  * New Features / Improvements
    + The canvas can now be scrolled horizontally by holding Shift while using the mouse wheel (#141)
    + The primary and secondary palette colors can now be swapped by pressing X (#147)
    + Added a more user-friendly dialog when attempting to open an unsupported file format (#143, #1856821)
    + Zooming in and out can now be done without pressing the Ctrl key (#150).
    + Arrow keys can be used to move by a single pixel in the Move Selected Pixels and Move Selection tools (#1906141).
    + Shift can now be used to constrain to a uniform scale when scaling using the Move Selected Pixels tool (#138).
    + The About dialog now allows easily copying the version information to the clipboard for use when reporting bugs (#1924249).
  * Changes
    + Fixed inconsistent behavior when switching between tools that share the same shortcut, such as the selection tools (#144, #1558767)
    + Improved error messages when the user does not have read or write permissions for a file (#1715150).
    + The appdata file is now installed to /usr/share/metainfo instead of the legacy path /usr/share/appdata (#186).
    + Tooltips for tabs now show the full file path instead of only the file name (#187).
  * Bug Fixes
    + Fixed a bug where Auto Crop could incorrectly remove an additional pixel on the bottom and right side of the image. (#1191390).
    + Fixed a bug where drawing a single pixel with the Pencil tool used black instead of the palette color (#1897245).
    + Fixed issues with the zoom controls when using a French locale (#1464855)
    + Fixed invalid URLs in pinta.appdata.xml (#140, #145)
    + Added missing release notes to pinta.appdata.xml (#142)
    + Fixed a regression introduced in Pinta 1.7 that could produce blurred pixels when using the Move Selected Pixels tool (#1904304).
    + Fixed a bug where the Rotate / Zoom Layer dialog could leave the layer in a state where all future actions were also transformed (#1905176).
    + Fixed a bug where the document might not be marked as modified after certain undo / redo actions (#1905165).
    + Fixed a bug where the Move Selected Pixels tool did not handle transparent pixels correctly (#1905706).
    + Fixed a bug where deselecting via a single click in the select tool could cause bugs with undoing earlier history items (#1905719).
    + Fixed a bug where the initial corner of a rectangle shape could be cut off (#1922470).
    + Fixed a bug where the text tool was not correctly clipped against the selection (#1910511).
    + Improved handling of memory allocation failures for large images (#776346).
    + Fixed a bug where the shape tools did not redraw after changes to the fill style until the cursor entered the canvas (#1937921).
    + Fixed a crash when opening an invalid palette file (#146, #1890450).
* Sun Aug 16 2020 GuinuxBR <guinuxbr@gmail.com>
- Update to version 1.7:
  * New Features / Improvements
    + Added a tab view to switch between images. The tabs can also be docked side-by-side or pulled into new windows. (#94).
    + The Rotate / Zoom dialog now supports zooming and panning (#1252756).
    + Added a Smooth Erase tool, which is enabled using the Type menu on the Erase tool's toolbar (#110).
    + The Pencil tool can switch between different blend modes (#124, #1688743).
    + Added support for JASC PaintShop Pro palette files (#126).
    + The transform tools can now rotate in fixed increments by holding Shift (#134).
    + The Move Selected tool can now scale by holding Ctrl (#138).
    + Dragging and dropping a URL (e.g. image from a web browser) to download and open the image is now supported (#80, #644123).
    + Performance improvements when interacting with selections, particularly for large images (#1428740).
    + The Rectangle Select tool now shows different arrow cursors at each corner of the selection (#1188143).
    + Added an AppData file for integration with some Linux app stores (#121).
    + A new user guide has been written for the Pinta website! Thanks to @jeneira94, @akaro2424, and @anadvu for their contributions!
  * Changes
    + .NET 4.5 / Mono 4.0 are now required.
    + Mono 6.x is strongly recommended for Mac and Linux users.
    + UI improvements to the New Image dialog (#99, [1424547).
    + The Rotate / Zoom dialog now rotates in-place instead of changing the layer's size.
    + Cairo blend operations are now used instead of PDN's managed blend modes (#98, #1248933, #1091910).
    + The tool windows can now only be closed with the View -> Tool Windows menu, as it was easy to accidentally close them without knowing how to recover them (#1428720).
    + The shortcut for the Intersect selection mode is now Alt + Left Click instead of using Shift, which had caused conflicts with holding Shift to constrain the selection to a square (#1426660).
  * Bug Fixes
    + Fixed many issues where selection changes did not update correctly (#1438022, #1188924, #1429830, #1098137, #105).
    + Fixed incorrect behaviour when using the Shift key to constrain to a square or circle in the Rectangle and Ellipse tools (#1452607).
    + The option to expand the canvas when pasting an image now only changes the canvas size in the dimension where the pasted image is larger (#1883623).
    + Fixed a bug where Auto Crop used the current layer instead of the entire image when deciding what to crop, and takes the selection into account (#1434928, #1434906).
    + Fixed potential crashes when switching tools without any open documents (#1425612).
    + Fixed a potential bug where the OK button in the New Image dialog could be incorrectly disabled (#1430203).
    + Fixed a crash when clicking on the Open Images pad after closing all images (#1430789).
    + Fixed a bug where the Levels dialog closed unexpectedly when clicking on one of the color checkboxes (#1435045).
    + The outline width settings on the Text Tool's toolbar now only show up if they are relevant to the stroke style being used (#1426663).
    + Fixed a potential crash creating gradients (#1446217).
    + Fixed issues where the selection handles disappeared after pressing Delete (#1424629).
    + Fixed several transparency-related issues with premultiplied alpha (#109, #113, #114, #117, #125).
    + Corrected display problems in the Move Selected Tool and live previews for effects (#115).
    + Add-ins can now load icons correctly (#116).
    + Fixed strange behaviour when the width or height of a drawn rounded rectangle is 0 (#112).
    + Fixed issues with the text tool on OSX (#1425749).
    + Fixed inconsistent labels in the UI (#1579033).
    + Fixed issues with the zoom tool under certain locales (#139, #133, #1464855).
    + Fixed issues when drawing on very zoomed-in images (#129, #133).
    + Fixed issues where brushes could draw outside the selection (#1775709).
    + Fixed issues with the docking library (#832395).
    + Fixed a bug where undoing a history item could set the background palette color to the foreground color (#1888131).
    + Fixed issues where the zoom level was not maintained when undoing a Crop to Selection (#1888885).
    + Fixed an error on newer Mono versions when opening URLs via the menu items under the Help menu (#1888883).
    + Fixed some occasional crashes on dragging and dropping or pasting into a new image (#1838620, #1508777).
    + Fixed issues where using the Rectangle Select tool after the Move Selection or Move Selected Pixels tools did not update correctly (#1889647, #1473430, #1889774).
    + Adjusted Pinta.Install.proj to simplify installing to a custom prefix (#781836).
* Tue Mar 31 2020 Karl Cheng <qantas94heavy@gmail.com>
- Fix unresolvable Mono addins dependency
* Thu Jun 11 2015 dimstar@opensuse.org
- Fix build with mono 4.0 (sed hacks borrowed from Fedora).
* Tue May 19 2015 mailaender@opensuse.org
- enable checks
* Wed Mar  4 2015 sor.alexei@meowr.ru
- Update to 1.6:
  * New Features / Improvements:
    + Redesigned shape tools (demo video):
  - The Line tool now supports drawing curves and arrows.
  - Shapes remain editable after being drawn.
  - All shape tools now support drawing dashed lines.
    + All selection tools now support the Union, Exclude, Xor, and
    Intersection modes.
    + New community add-in repository - add-ins can be installed
    through the Add-in Manager dialog (via the Add-ins menu).
    + Redesigned New Image dialog, which includes presets,
    orientation and background options, and a thumbnail preview
    of the image.
    + The toolbox and color palette now have a flexible layout and
    can expand horizontally, making them significantly more
    usable on small screens.
    + When launching Pinta from the command line, the standard
  - -version and --help options are now supported.
  * Bug Fixes:
    + Fix a number of issues with the text tool’s support for
    Unicode text.
    + Fix a number of issues with undoing selections.
    + Fix a number of untranslatable strings throughout Pinta, and
    the zoom toolbar’s percentages are now formatted using the
    current locale.
    + The text tool now supports the standard shortcuts for
    toggling bold (Ctrl+B), italic (Ctrl+I), and underline
    (Ctrl+U), and all of the text can be selected with Ctrl+A.
    + Fix a potential crash after undoing a text action.
    + Fix a crash when holding both the left and right mouse
    buttons with the Pencil tool.
    + Fix issues with zooming in very far on large images.
    + Fix a potential crash when exiting Pinta.
    + Fix issues with the toolbar’s state (hidden vs. visible) not
    being preserved after re-opening Pinta.
    + Fix several bugs where undo did not work correctly for the
    Freeform Shape tool.
    + Fix a bug where resizing a selection allowed the selection to
    grow beyond the edge of the canvas.
    + The selection handles are now larger and easier to click.
    + Fix bugs where using the Recolor tool after the Line/Curve
    tool resulted in odd behavior.
    + The error dialog now includes a link to the bug tracker.
    + Improve the error message when opening an unsupported file
    format.
    + Fix an issue where cancelling the saving of a jpg image made
    it appear that the image had actually been saved.
    + Auto-hiding now works correctly for the history and open
    images pads.
    + Auto Crop now works correctly if there is an active selection.
    + The progress dialog is now modal.
    + The Backspace and Delete keys are now usable when editing
    text fields in the toolbar.
    + Improve the readability of the text cursor against dark
    backgrounds.
- Spec cleanup.
- Add pinta-lang package.
* Mon May 26 2014 develop7@develop7.info
- update to v1.5
  * see https://github.com/PintaProject/Pinta/releases/tag/1.5
* Sat Apr 12 2014 mailaender@opensuse.org
- added %%post macros
* Thu Sep 27 2012 i@marguerite.su
- update to 1.4
  * http://pinta-project.com/Releases.Release%%201-4.ashx
* Wed Jun 13 2012 mailaender@opensuse.org
- Update to 1.3
  * http://pinta-project.com/Releases.1-3.ashx
* Wed Apr 18 2012 i@marguerite.su
- update to 1.1
  * http://pinta-project.com/Releases.1-1.ashx
* Thu Apr 28 2011 ajorgensen@novell.com
- Update to 1.0
  * http://pinta-project.com/Release-Notes-1-0.ashx
* Fri Jan 14 2011 malcolmlewis@opensuse.org
- Add missing Url tag
* Wed Jan 12 2011 malcolmlewis@opensuse.org
- Update to 0.6
  http://pinta-project.com/release/0.6
- Spec file cleanup
- Desktop patch dropped
* Fri Jul  9 2010 ajorgensen@novell.com
- Update to 0.4
  http://pinta-project.com/release/0.4
* Mon May 24 2010 ajorgensen@novell.com
- Update to 0.3
  http://pinta-project.com/release/0.3
* Mon Mar 15 2010 ajorgensen@novell.com
- Update to 0.2
  http://www.pinta-project.com/release/0.2
* Mon Mar  8 2010 ajorgensen@novell.com
- First version (0.1)
